import{d as l,ex as i,c as r,o,a5 as t,h as c,e9 as _,ec as p,_ as u}from"./jwt-decode.esm.43a112d3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="ad2ec7e9-c187-4445-94bf-28e40c3af933",e._sentryDebugIdIdentifier="sentry-dbid-ad2ec7e9-c187-4445-94bf-28e40c3af933")}catch{}})();const f={class:"logo"},g=["src","alt"],m=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const s=e;i(a=>({"4521d904":n.value}));const n=r(()=>s.size==="small"?"24px":s.size==="large"?"80px":"50px"),d=r(()=>`${s.brandName} Logo`);return(a,y)=>(o(),t("div",f,[a.imageUrl?(o(),t("img",{key:0,class:"logo-img",src:a.imageUrl,alt:d.value},null,8,g)):c("",!0),a.hideText?c("",!0):(o(),t("span",{key:1,class:_(a.size)},p(a.brandName),3))]))}});const h=u(m,[["__scopeId","data-v-8f34aac0"]]);export{h as L};
//# sourceMappingURL=Logo.69d41676.js.map
