import{O as a}from"./OmniChat.8b7e3a12.js";import{u as s}from"./omniChatStore.d50d5d5e.js";import{d as i,ea as c,u as t,o as d,a as l,h as u}from"./jwt-decode.esm.43a112d3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="ebb81a00-19d6-490a-beb7-da1bd0454a2e",e._sentryDebugIdIdentifier="sentry-dbid-ebb81a00-19d6-490a-beb7-da1bd0454a2e")}catch{}})();const _=i({__name:"ConsoleOmniChat",setup(e){const n=c().params.projectId,o=s();return o.init("console",n),(p,m)=>t(o).controller&&t(o).repository?(d(),l(a,{key:0,"ai-chat-repository":t(o).repository,controller:t(o).controller,environment:{origin:"console",projectId:t(n)}},null,8,["ai-chat-repository","controller","environment"])):u("",!0)}});export{_};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.41a88768.js.map
