import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.41e75dde.js";import{d as i,ea as a,a as s,u as m,o as c}from"./jwt-decode.esm.43a112d3.js";import"./router.663c6f19.js";import"./index.919e954c.js";import"./fetch.1c08a6db.js";import"./record.dfeaef8c.js";import"./SaveButton.6fbb5eba.js";import"./ExclamationCircleOutlined.b1f7821e.js";import"./CrudView.2286e2df.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.66110338.js";import"./constants.c15d871e.js";import"./url.b9e6dfc2.js";import"./PhDotsThreeVertical.vue.b0448dae.js";import"./index.b0d2e208.js";import"./asyncComputed.3d996402.js";import"./polling.6894c3b9.js";import"./omniChatStore.d50d5d5e.js";import"./uuid.002be344.js";import"./PhCopySimple.vue.50d54635.js";import"./PhPencil.vue.127e2625.js";import"./index.9422ca29.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="ebaa863c-ebc7-4b7b-84cd-9af1f844a524",o._sentryDebugIdIdentifier="sentry-dbid-ebaa863c-ebc7-4b7b-84cd-9af1f844a524")}catch{}})();const z=i({__name:"EnvVars",setup(o){const e=a().params.projectId,t=new p(e);return(d,f)=>(c(),s(n,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars.2059b361.js.map
