import{C as r,E as t,K as i,a as c,M as f,c as b,P as l,R as y,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.59331e39.js";import"./jwt-decode.esm.43a112d3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="16b99812-3d3c-435c-9b51-daa2512fa7dd",e._sentryDebugIdIdentifier="sentry-dbid-16b99812-3d3c-435c-9b51-daa2512fa7dd")}catch{}})();export{r as CancellationTokenSource,t as Emitter,i as KeyCode,c as KeyMod,f as MarkerSeverity,b as MarkerTag,l as Position,y as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.57efa0ca.js.map
