import{h as n}from"./router.663c6f19.js";import"./jwt-decode.esm.43a112d3.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="171e0b3d-4ddc-422b-91ae-506af46ddc0b",t._sentryDebugIdIdentifier="sentry-dbid-171e0b3d-4ddc-422b-91ae-506af46ddc0b")}catch{}})();class o{async create(e){return n.post(`organizations/${e.organizationId}/members`,{email:e.email,teams:e.teams})}async delete(e){return n.delete(`organizations/${e.organizationId}/members/${e.authorId}`)}async list(e){return n.get(`organizations/${e}/members`)}async get(e,r){return n.get(`organizations/${e}/members/${r}`)}async update(e,r,a){return n.patch(`organizations/${e}/members/${r}`,a)}}export{o as M};
//# sourceMappingURL=member.47961d18.js.map
