import{f as a,e7 as d,eY as o}from"./jwt-decode.esm.43a112d3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="fda33f2e-db23-4875-a79f-f7415daeefdb",e._sentryDebugIdIdentifier="sentry-dbid-fda33f2e-db23-4875-a79f-f7415daeefdb")}catch{}})();function l(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(f){return Object.getOwnPropertyDescriptor(r,f).enumerable}))),n.forEach(function(f){u(e,f,r[f])})}return e}function u(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var i=function(t,r){var n=l({},t,r.attrs);return a(d,l({},n,{icon:o}),null)};i.displayName="CloseCircleOutlined";i.inheritAttrs=!1;const s=i;export{s as C};
//# sourceMappingURL=CloseCircleOutlined.ddfcc458.js.map
