import{O as r}from"./index.66339d8b.js";import{d as l,k as i,a5 as c,f as t,b as n,u as o,o as u,g as s,A as f,da as _}from"./jwt-decode.esm.43a112d3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="d6e1a11f-3a50-48a8-9cf3-1c599c64eb52",e._sentryDebugIdIdentifier="sentry-dbid-d6e1a11f-3a50-48a8-9cf3-1c599c64eb52")}catch{}})();const p=l({__name:"OidcLoginCallback",setup(e){return i(async()=>{await new r().loginCallback()}),(a,d)=>(u(),c("div",null,[t(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),t(o(_),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{p as default};
//# sourceMappingURL=OidcLoginCallback.5581bbfc.js.map
