import{L as n}from"./Logo.69d41676.js";import{d as r,o as a,a as d,u as i}from"./jwt-decode.esm.43a112d3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="78ce693b-78b1-4814-9017-19380fb2b5bd",e._sentryDebugIdIdentifier="sentry-dbid-78ce693b-78b1-4814-9017-19380fb2b5bd")}catch{}})();const b="/assets/logo.0faadfa2.svg",u=r({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(s,t)=>{var o;return a(),d(n,{"image-url":i(b),"brand-name":"Abstra","hide-text":s.hideText,size:(o=s.size)!=null?o:"small"},null,8,["image-url","hide-text","size"])}}});export{u as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.a762856f.js.map
