import"./jwt-decode.esm.43a112d3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="c98030d9-ed08-49da-bbf5-fc49cfc126f0",e._sentryDebugIdIdentifier="sentry-dbid-c98030d9-ed08-49da-bbf5-fc49cfc126f0")}catch{}})();const t=(...e)=>window.fetch(...e);export{t as l};
//# sourceMappingURL=fetch.1c08a6db.js.map
