import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.f79bb238.js";import{d as m,e5 as f,ea as g,a5 as y,f as b,u as n,o as w,_ as k}from"./jwt-decode.esm.43a112d3.js";import{u as h}from"./workspaceStore.0cebb1b1.js";import"./index.66339d8b.js";import"./CircularLoading.96a428f8.js";import"./Logo.69d41676.js";import"./string.9f615d28.js";import"./index.9422ca29.js";import"./userStore.05a27538.js";import"./url.b9e6dfc2.js";import"./colorHelpers.e223244b.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="22df5593-c598-42da-9961-3529c89d753a",e._sentryDebugIdIdentifier="sentry-dbid-22df5593-c598-42da-9961-3529c89d753a")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=f(),t=g(),r=h(),_=async()=>{const{redirect:a,...s}=t.query;if(a){await o.push({path:a,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>{var c,d,p,u,i;return w(),y("div",v,[b(l,{"logo-url":(d=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const U=k(I,[["__scopeId","data-v-cb33c596"]]);export{U as default};
//# sourceMappingURL=Login.d7d7849b.js.map
