import{O as d}from"./index.66339d8b.js";import{d as l,k as u,a5 as i,f as a,b as n,u as o,o as c,g as s,A as f,da as _}from"./jwt-decode.esm.43a112d3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="1662a157-8723-4438-a88c-5ff29c77097f",e._sentryDebugIdIdentifier="sentry-dbid-1662a157-8723-4438-a88c-5ff29c77097f")}catch{}})();const b=l({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new d().logoutCallback()}),(t,r)=>(c(),i("div",null,[a(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),a(o(_),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{b as default};
//# sourceMappingURL=OidcLogoutCallback.c6557b98.js.map
