import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.a762856f.js";import{B as m}from"./BaseLayout.e025a68e.js";import{d as l,ae as y,c1 as b,_ as u,aZ as v,a_ as g,o as _,a5 as h,e as r,a6 as n,ea as w,e5 as S,k,a as L,b as s,f as i,u as x}from"./jwt-decode.esm.43a112d3.js";import{u as B}from"./editor.26eb95e9.js";import{b as I}from"./index.436f0d8a.js";import"./Logo.69d41676.js";import"./workspaceStore.0cebb1b1.js";import"./userStore.05a27538.js";import"./url.b9e6dfc2.js";import"./colorHelpers.e223244b.js";import"./index.66339d8b.js";import"./linters.b7d8e6a2.js";import"./asyncComputed.3d996402.js";import"./constants.c15d871e.js";import"./index.919e954c.js";import"./index.ab2ebf58.js";import"./index.b0d2e208.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="bf96b665-f993-420b-8232-6ca008baaba8",e._sentryDebugIdIdentifier="sentry-dbid-bf96b665-f993-420b-8232-6ca008baaba8")}catch{}})();const $=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const a=y({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(a)}}});const P={class:"v-spinner"};function D(e,a,o,d,c,p){return v((_(),h("div",P,[r("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-even",style:n(e.spinnerStyle)},null,4),r("div",{class:"v-beat v-beat-odd",style:n(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const R=u($,[["render",D],["__scopeId","data-v-06538001"]]),j={class:"content"},z=l({__name:"ProjectLogin",setup(e){const a=w(),o=S(),d=B();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),o.replace(t.pathname+t.search)}function p(){const t=a.query["api-key"];if(typeof t=="string")return t}return k(async()=>{const t=p();if(!t){o.push({name:"error"});return}await d.createLogin(t).then(c),o.push({name:"editor"})}),(t,C)=>(_(),L(m,null,{navbar:s(()=>[i(x(I),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:s(()=>[i(f)]),_:1})]),content:s(()=>[r("div",j,[i(R)])]),_:1}))}});const X=u(z,[["__scopeId","data-v-d2a19803"]]);export{X as default};
//# sourceMappingURL=ProjectLogin.17e29012.js.map
