import{d as o,a5 as d,e as s,a7 as f,e9 as n,o as l,_ as r}from"./jwt-decode.esm.43a112d3.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="488f21bf-fab7-4ece-a9d3-ad9bea4920f1",t._sentryDebugIdIdentifier="sentry-dbid-488f21bf-fab7-4ece-a9d3-ad9bea4920f1")}catch{}})();const i=o({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean}},setup(t){return(e,a)=>(l(),d("div",{class:n(["content-layout",{"no-padding":e.noPadding}])},[s("div",{class:n(["centered-layout",{"full-width":e.fullWidth}])},[f(e.$slots,"default",{},void 0,!0)],2)],2))}});const _=r(i,[["__scopeId","data-v-fb4d67f9"]]);export{_ as C};
//# sourceMappingURL=ContentLayout.c6a23f4c.js.map
