import{y as n,z as r,B as o,C as d,P as p,D as c,E as m,F as u,G as i,H as f,I as g,J as y,K as b}from"./jwt-decode.esm.43a112d3.js";import{a as l,b as a}from"./workspaceStore.0cebb1b1.js";import{s as w}from"./index.66339d8b.js";import{_ as I}from"./App.vue_vue_type_style_index_0_lang.92344c08.js";import"./userStore.05a27538.js";import"./url.b9e6dfc2.js";import"./colorHelpers.e223244b.js";import"./PlayerConfigProvider.7e78c644.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="339e1524-1342-4911-810d-d48053868ddd",t._sentryDebugIdIdentifier="sentry-dbid-339e1524-1342-4911-810d-d48053868ddd")}catch{}})();class _{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await w();const t=await l(),s=n(),e=r({render:()=>f(I)});o.init(),d(e,a,t),_.init(),e.use(a),e.use(s),e.use(p),e.mount("#app"),e.component("VSelect",c),e.component("Markdown",m),e.component("Message",u),i(e,g),i(e,y),i(e,b)})();
//# sourceMappingURL=player.17af4728.js.map
