import{P as f}from"./PlayerNavbar.fe7bffc9.js";import{d as g,e5 as h,ea as i,r as y,c as k,m as v,a5 as w,u as n,a as b,h as L,e as C,f as I,o as c,_ as N}from"./jwt-decode.esm.43a112d3.js";import{u as V}from"./workspaceStore.0cebb1b1.js";import"./userStore.05a27538.js";import"./index.66339d8b.js";import"./metadata.becf85f9.js";import"./PhWebhooksLogo.vue.9a8515b7.js";import"./LoadingOutlined.80331cab.js";import"./PhSignOut.vue.dd085aeb.js";import"./index.ab2ebf58.js";import"./url.b9e6dfc2.js";import"./colorHelpers.e223244b.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="fa4c1917-7010-4475-9d0a-8f94926a1690",o._sentryDebugIdIdentifier="sentry-dbid-fa4c1917-7010-4475-9d0a-8f94926a1690")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),u=i().path,a=y(null),d=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=k(()=>!!i().meta.hideLogin);return(r,s)=>{const m=v("RouterView");return c(),w("div",x,[n(t).state.workspace?(c(),b(f,{key:0,"current-path":n(u),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:d,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const G=N(D,[["__scopeId","data-v-f095bece"]]);export{G as default};
//# sourceMappingURL=Main.9ddb8f02.js.map
