import{X as d,dL as c,dM as i}from"./jwt-decode.esm.43a112d3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="e8b34d1b-c160-4abd-8273-8480af0a3149",e._sentryDebugIdIdentifier="sentry-dbid-e8b34d1b-c160-4abd-8273-8480af0a3149")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:b,QuarterPicker:a,RangePicker:o}=c(i),u=d(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:o,TimePicker:b,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(a.name,a),e)});export{u as D,r as M,a as Q,o as R,t as W};
//# sourceMappingURL=dayjs.4e6f6b98.js.map
