import{d as o,o as c,a5 as s,f as a,u as d,S as _,_ as r}from"./jwt-decode.esm.43a112d3.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="4108539d-46f3-4ce8-8cc9-08ec7cfcf941",e._sentryDebugIdIdentifier="sentry-dbid-4108539d-46f3-4ce8-8cc9-08ec7cfcf941")}catch{}})();const f={class:"centered"},i=o({__name:"LoadingContainer",setup(e){return(n,t)=>(c(),s("div",f,[a(d(_))]))}});const u=r(i,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.4bbdf540.js.map
